@@ -7,7 +7,7 @@
 ;;         Yasutaka SHINDOH <ring-pub@fan.gr.jp>
 ;;         Oscar Bonilla    <ob@bitmover.com>
 ;; Created: 2001/06/28
-;; Revised: 2007/06/26
+;; Revised: 2007/08/17
 ;; Keywords: font-lock emacs-lisp change-log texinfo c java perl html
 ;;           tcl ruby mail news
 
@@ -213,7 +213,7 @@
 
 ;;; Code:
 
-(defconst develock-version "0.34"
+(defconst develock-version "0.35"
   "Version number for this version of Develock.")
 
 (require 'advice)
@@ -851,20 +851,7 @@ Each element should be triple symbols of the following form:
      (1 'develock-long-line-1 append)
      (2 'develock-long-line-2 append))
     ;; an ugly entry line
-    ("^\\( +\\|\t[\t ]*\\)?\\(?:[12][0-9][0-9][0-9]-[01][0-9]-[0-3][0-9]\
-\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[012][0-9]:[0-5][0-9]:[0-5][0-9]\\)?\
-\\|\\(?:Sun\\|Mon\\|Tue\\|Wed\\|Thu\\|Fri\\|Sat\\)\
-\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)\
-\\(?:Jan\\|Feb\\|Mar\\|Apr\\|May\\|Jun\\|Jul\\|Aug\\|Sep\\|Oct\\|Nov\\|Dec\\)\
-\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[ 0-3][0-9]\
-\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[012][0-9]:[0-5][0-9]:[0-5][0-9]\
-\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[12][0-9][0-9][0-9]\\)\
-\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)[^\t <>]+\
-\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[^\t <>]+\\)?\
-\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[^\t <>]+\\)?\
-\\(\\(?:[\t ]+[^\t <>]+\\)*\\)\
-\\(?:\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)<\\|\\(<\\)\\)[^<>]+>\
-\\(?:\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)\(\\|\\([^\n ].*\\)\\)?"
+    (develock-find-ugly-change-log-entry-line
      (1 'develock-whitespace-1 nil t)
      (2 'develock-whitespace-1 t t)
      (3 'develock-whitespace-1 t t)
@@ -1437,6 +1424,30 @@ non-nil and sets beginning and ending points as the `match-data' #0,
 		       "\\(\t+\\)")
 		     limit t))
 
+(defun develock-find-ugly-change-log-entry-line (limit)
+  "Find an ugly entry line between the point and LIMIT in ChangeLog file."
+  (and (re-search-forward "\
+^\\( +\\|\t[\t ]*\\)?\\(?:[12][0-9][0-9][0-9]-[01][0-9]-[0-3][0-9]\
+\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[012][0-9]:[0-5][0-9]:[0-5][0-9]\\)?\
+\\|\\(?:Sun\\|Mon\\|Tue\\|Wed\\|Thu\\|Fri\\|Sat\\)\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)\
+\\(?:Jan\\|Feb\\|Mar\\|Apr\\|May\\|Jun\\|Jul\\|Aug\\|Sep\\|Oct\\|Nov\\|Dec\\)\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[ 0-3][0-9]\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[012][0-9]:[0-5][0-9]:[0-5][0-9]\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[12][0-9][0-9][0-9]\\)\
+\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)[^\t <>]+\
+\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[^\t <>]+\\)?\
+\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[^\t <>]+\\)?\
+\\(\\(?:[\t ]+[^\t <>]+\\)*\\)\
+\\(?:\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)<\\|\\(<\\)\\)[^<>]+>\
+\\(?:\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)\(\\|\\([^\n ].*\\)\\)?"
+			  limit t)
+       (prog2
+	   (goto-char (match-beginning 0))
+	   (or (not (zerop (forward-line -1)))
+	       (save-match-data (looking-at "[\t ]*$")))
+	 (goto-char (match-end 0)))))
+
 (eval-when-compile
   (defvar lisp-interaction-mode-hook))
 
